@@ -401,8 +401,9 @@ class Setup : public SetupBase
             // Process ifconfig and topology
             if (!l2_post)
             {
-                // set lowest interface metric to make Windows use pushed DNS search domain
-                create.add(new WinCmd("netsh interface ip set interface " + tap_index_name + " metric=1"));
+                // set high metric on interface so that rogue route which Windows creates (0.0.0.0/0)
+                // won't affect anything
+                create.add(new WinCmd("netsh interface ip set interface " + tap_index_name + " metric=9000"));
 
                 const std::string metric = route_metric_opt(pull, *local4, MT_IFACE);
                 const std::string netmask = IPv4::Addr::netmask_from_prefix_len(local4->prefix_length).to_string();
@@ -421,15 +422,22 @@ class Setup : public SetupBase
                 // specifying 'gateway' when setting ip address makes Windows add unnecessary route 0.0.0.0/0,
                 // which might cause routing conflicts, so we have to delete it after a small delay.
                 // If route is deleted before profile is created, then profile won't be created at all (OVPN-135)
-                WinCmd::Ptr cmd = new WinCmd("netsh interface ip delete route 0.0.0.0/0 " + tap_index_name + ' ' + local4->gateway + " store=active");
+                WinCmd::Ptr cmd_delroute = new WinCmd("netsh interface ip delete route 0.0.0.0/0 " + tap_index_name + ' ' + local4->gateway + " store=active");
+
+                // set lowest interface metric to make Windows use pushed DNS search domain
+                WinCmd::Ptr cmd_setmetric = new WinCmd("netsh interface ip set interface " + tap_index_name + " metric=1");
+
                 delete_route_timer.expires_after(Time::Duration::seconds(5));
-                delete_route_timer.async_wait([self = Ptr(this), cmd = std::move(cmd)](const openvpn_io::error_code &error)
+                delete_route_timer.async_wait([self = Ptr(this),
+                                               cmd_delroute = std::move(cmd_delroute),
+                                               cmd_setmetric = std::move(cmd_setmetric)](const openvpn_io::error_code &error)
                                               {
-						if (!error)
-						  {
-						    std::ostringstream os;
-						    cmd->execute(os);
-						  } });
+                        if (!error)
+                        {
+                            std::ostringstream os;
+                            cmd_delroute->execute(os);
+                            cmd_setmetric->execute(os);
+                        } });
             }
         }
 
@@ -549,7 +557,8 @@ class Setup : public SetupBase
         if (pull.reroute_gw.ipv4)
         {
             // get default gateway
-            const Util::BestGateway gw{AF_INET, pull.remote_address.address, tap.index};
+            ADDRESS_FAMILY af = pull.remote_address.ipv6 ? AF_INET6 : AF_INET;
+            const Util::BestGateway gw{af, pull.remote_address.address, tap.index};
 
             if (!gw.local_route())
             {
